@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Copyright (c) 2014 Bryant E. McDonnell
+# Copyright (c) 2023 Bryant E. McDonnell (See AUTHORS)
 #
 # Licensed under the terms of the BSD2 License
 # See LICENSE.txt for details
@@ -13,17 +13,18 @@ from pyswmm.lidcontrols import LidControls, LidControl
 from pyswmm.lidgroups import LidGroups, LidGroup, LidUnit
 from pyswmm.nodes import Node, Nodes
 from pyswmm.simulation import Simulation
+from pyswmm.output import Output
 from pyswmm.subcatchments import Subcatchment, Subcatchments
 from pyswmm.system import SystemStats
 from pyswmm.raingages import RainGages, RainGage
 
-VERSION_INFO = (1, 0, 1)
+VERSION_INFO = (1, 5, 0)
 
 __version__ = '.'.join(map(str, VERSION_INFO))
-__author__ = 'Bryant E. McDonnell (EmNet LLC) - bemcdonnell@gmail.com'
-__copyright__ = 'Copyright (c) 2016 Bryant E. McDonnell (See AUTHORS)'
+__author__ = 'Bryant E. McDonnell (Hydroinformatics, LLC) - bemcdonnell@gmail.com'
+__copyright__ = 'Copyright (c) 2023 Bryant E. McDonnell (See AUTHORS)'
 __licence__ = 'BSD2'
 __all__ = [
     Link, Links, LidControls, LidGroups, Node, Nodes, Subcatchment, Subcatchments, Simulation,
-    SystemStats, RainGages, RainGage
+    SystemStats, RainGages, RainGage, Output
 ]
