@@ -23,34 +23,33 @@ class Links(object):
 
     >>> from pyswmm import Simulation, Links
     >>>
-    >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+    >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
     ...     for link in Links(sim):
-    ...         print link
-    ...         print link.linkid
-    ...
-    >>> <swmm5.Link object at 0x031B0350>
-    >>> C1
-    >>> <swmm5.Link object at 0x030693D0>
-    >>> C2
-    >>> <swmm5.Link object at 0x031B0350>
-    >>> C3
-    >>> <swmm5.Link object at 0x030693D0>
-    >>> C0
+    ...         print(link)
+    ...         print(link.linkid)
+    <swmm5.Link object at 0x031B0350>
+    C1
+    <swmm5.Link object at 0x030693D0>
+    C2
+    <swmm5.Link object at 0x031B0350>
+    C3
+    <swmm5.Link object at 0x030693D0>
+    C0
 
     Iterating or Links Object
 
     >>> links = Links(sim)
     >>> for link in links:
-    ...     print link.linkid
-    >>> C1:C2
-    >>> C2
-    >>> C3
+    ...     print(link.linkid)
+    C1:C2
+    C2
+    C3
 
     Testing Existence
 
     >>> links = Links(sim)
     >>> "C1:C2" in links
-    >>> True
+    True
 
     Initializing a link Object
 
@@ -58,7 +57,7 @@ class Links(object):
     >>> c1c2 = links['C1:C2']
     >>> c1c2.flow_limit = 12
     >>> c1c2.flow_limit
-    >>> 12
+    12
     """
 
     def __init__(self, model):
@@ -109,8 +108,6 @@ class Links(object):
         else:
             raise StopIteration()
 
-    next = __next__  # Python 2
-
     @property
     def _linkid(self):
         """Link ID."""
@@ -128,12 +125,12 @@ class Link(object):
 
     >>> from pyswmm import Simulation, Links
     >>>
-    >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+    >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
     ...     c1c2 = Links(sim)["C1:C2"]
-    ...     print c1c2.flow
-    ...     for step in simulation:
-    ...         print c1c2.flow
-    ... 0.0
+    ...     print(c1c2.flow)
+    ...     for step in sim:
+    ...         print(c1c2.flow)
+    0.0
     """
 
     def __init__(self, model, linkid):
@@ -158,10 +155,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.linkid
-        >>> "C1"
+        ...     print(c1c2.linkid)
+        "C1"
         """
         return self._linkid
 
@@ -176,10 +173,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.is_conduit()
-        >>> True
+        ...     print(c1c2.is_conduit())
+        True
         """
         return self._model.getLinkType(self._linkid) is shared_enum.LinkType.CONDUIT
 
@@ -194,10 +191,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.is_pump()
-        >>> False
+        ...     print(c1c2.is_pump())
+        False
         """
         return self._model.getLinkType(self._linkid) is shared_enum.LinkType.PUMP
 
@@ -212,10 +209,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.is_orifice()
-        >>> False
+        ...     print(c1c2.is_orifice())
+        False
         """
         return self._model.getLinkType(self._linkid) is shared_enum.LinkType.ORIFICE
 
@@ -230,10 +227,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.is_weir()
-        >>> False
+        ...     print(c1c2.is_weir())
+        False
         """
         return self._model.getLinkType(self._linkid) is shared_enum.LinkType.WEIR
 
@@ -248,10 +245,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.is_outlet()
-        >>> False
+        ...     print(c1c2.is_outlet())
+        False
         """
         return self._model.getLinkType(self._linkid) is shared_enum.LinkType.OUTLET
 
@@ -267,10 +264,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.connections
-        >>> ("C1","C2")
+        ...     print(c1c2.connections)
+        ("C1","C2")
         """
         return self._model.getLinkConnections(self._linkid)
 
@@ -286,10 +283,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.inlet_node
-        >>> C1
+        ...     print(c1c2.inlet_node)
+        C1
         """
         return self._model.getLinkConnections(self._linkid)[0]
 
@@ -305,10 +302,10 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.outlet_node
-        >>> C2
+        ...     print(c1c2.outlet_node)
+        C2
         """
         return self._model.getLinkConnections(self._linkid)[1]
 
@@ -324,22 +321,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.inlet_offset
-        >>> 0.1
+        ...     print(c1c2.inlet_offset)
+        0.1
 
         Setting the value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.inlet_offset
+        ...     print(c1c2.inlet_offset)
         ...     c1c2.inlet_offset = 0.2
-        ...     print c1c2.inlet_offset
-        >>> 0.1
-        >>> 0.2
+        ...     print(c1c2.inlet_offset)
+        0.1
+        0.2
         """
         return self._model.getLinkParam(self._linkid, LinkParams.offset1.value)
 
@@ -347,9 +344,9 @@ class Link(object):
     def inlet_offset(self, param):
         """Set Link Upstream Link Offset."""
         self._model.setLinkParam(self._linkid, LinkParams.offset1.value, param)
-
     @property
     def outlet_offset(self):
+
         """
         Get/set Downstream Offset Depth.
 
@@ -360,22 +357,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.outlet_offset
-        >>> 0.1
+        ...     print(c1c2.outlet_offset)
+        0.1
 
         Setting the value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.outlet_offset
+        ...     print(c1c2.outlet_offset)
         ...     c1c2.outlet_offset = 0.2
-        ...     print c1c2.outlet_offset
-        >>> 0.1
-        >>> 0.2
+        ...     print(c1c2.outlet_offset)
+        0.1
+        0.2
         """
         return self._model.getLinkParam(self._linkid, LinkParams.offset2.value)
 
@@ -396,22 +393,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.initial_flow
-        >>> 0
+        ...     print(c1c2.initial_flow)
+        0
 
         Setting the Value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.initial_flow
+        ...     print(c1c2.initial_flow)
         ...     c1c2.initial_flow = 0.2
-        ...     print c1c2.initial_flow
-        >>> 0.1
-        >>> 0.2
+        ...     print(c1c2.initial_flow)
+        0.1
+        0.2
         """
         return self._model.getLinkParam(self._linkid, LinkParams.q0.value)
 
@@ -432,22 +429,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.flow_limit
-        >>> 0
+        ...     print(c1c2.flow_limit)
+        0
 
         Setting the Value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.flow_limit
+        ...     print(c1c2.flow_limit)
         ...     c1c2.flow_limit = 0.2
-        ...     print c1c2.flow_limit
-        >>> 0
-        >>> 0.2
+        ...     print(c1c2.flow_limit)
+        0
+        0.2
         """
         return self._model.getLinkParam(self._linkid, LinkParams.qLimit.value)
 
@@ -468,22 +465,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.inlet_head_loss
-        >>> 0
+        ...     print(c1c2.inlet_head_loss)
+        0
 
         Setting the Value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.inlet_head_loss
+        ...     print(c1c2.inlet_head_loss)
         ...     c1c2.inlet_head_loss = 0.2
-        ...     print c1c2.inlet_head_loss
-        >>> 0
-        >>> 0.2
+        ...     print(c1c2.inlet_head_loss)
+        0
+        0.2
         """
         return self._model.getLinkParam(self._linkid,
                                         LinkParams.cLossInlet.value)
@@ -506,22 +503,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.outlet_head_loss
-        >>> 0
+        ...     print(c1c2.outlet_head_loss)
+        0
 
         Setting the Value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.outlet_head_loss
+        ...     print(c1c2.outlet_head_loss)
         ...     c1c2.outlet_head_loss = 0.2
-        ...     print c1c2.outlet_head_loss
-        >>> 0
-        >>> 0.2
+        ...     print(c1c2.outlet_head_loss)
+        0
+        0.2
         """
         return self._model.getLinkParam(self._linkid,
                                         LinkParams.cLossOutlet.value)
@@ -544,22 +541,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.average_head_loss
-        >>> 0
+        ...     print(c1c2.average_head_loss)
+        0
 
         Setting the value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.average_head_loss
+        ...     print(c1c2.average_head_loss)
         ...     c1c2.average_head_loss = 0.2
-        ...     print c1c2.average_head_loss
-        >>> 0
-        >>> 0.2
+        ...     print(c1c2.average_head_loss)
+        0
+        0.2
         """
         return self._model.getLinkParam(self._linkid,
                                         LinkParams.cLossAvg.value)
@@ -582,22 +579,22 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.seepage_rate
-        >>> 0
+        ...     print(c1c2.seepage_rate)
+        0
 
         Setting the Value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
-        ...     print c1c2.seepage_rate
+        ...     print(c1c2.seepage_rate)
         ...     c1c2.seepagerate = 0.2
-        ...     print c1c2.seepage_rate
-        >>> 0
-        >>> 0.2
+        ...     print(c1c2.seepage_rate)
+        0
+        0.2
         """
         return self._model.getLinkParam(self._linkid,
                                         LinkParams.seepRate.value)
@@ -623,15 +620,15 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.flow
-        >>> 0
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        ...         print(c1c2.flow)
+        0
+        1.2
+        1.5
+        1.9
+        1.2
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.newFlow.value)
@@ -651,15 +648,15 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.depth
-        >>> 0
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        ...         print(c1c2.depth)
+        0
+        1.2
+        1.5
+        1.9
+        1.2
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.newDepth.value)
@@ -679,15 +676,15 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.volume
-        >>> 0
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        ...         print(c1c2.volume)
+        0
+        1.2
+        1.5
+        1.9
+        1.2
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.newVolume.value)
@@ -707,15 +704,15 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.froude
-        >>> 0
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        ...         print(c1c2.froude)
+        0
+        1.2
+        1.5
+        1.9
+        1.2
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.froude.value)
@@ -735,15 +732,15 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.ups_xsection_area
-        >>> 0
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        ...         print(c1c2.ups_xsection_area)
+        0
+        1.2
+        1.5
+        1.9
+        1.2
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.surfArea1.value)
@@ -763,15 +760,15 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.ds_xsection_area
-        >>> 0
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        ...         print(c1c2.ds_xsection_area)
+        0
+        1.2
+        1.5
+        1.9
+        1.2
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.surfArea2.value)
@@ -791,15 +788,15 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.current_setting
-        >>> 0
-        >>> 1
-        >>> 0
-        >>> 0.5
-        >>> 1
+        ...         print(c1c2.current_setting)
+        0
+        1
+        0
+        0.5
+        1
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.setting.value)
@@ -819,31 +816,31 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.target_setting
-        >>> 0
-        >>> 0
-        >>> 1
-        >>> 0.5
-        >>> 1
+        ...         print(c1c2.target_setting)
+        0
+        0
+        1
+        0.5
+        1
 
         Setting the Value
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     c1c2 = Links(sim)["C1:C2"]
         ...     for step in sim:
-        ...         print c1c2.target_setting
+        ...         print(c1c2.target_setting)
         ...         if c1c2.flow > 3:
         ...             c1c2.target_setting = 0.1
-        >>> 0
-        >>> 0
-        >>> 0.1
-        >>> 0.1
-        >>> 0.1
+        0
+        0
+        0.1
+        0.1
+        0.1
         """
         return self._model.getLinkResult(self._linkid,
                                          LinkResults.targetSetting.value)
@@ -873,13 +870,13 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/buildup-test.inp') as sim:
-        ...     C1 = Nodes(sim)["C1"]
+        >>> with Simulation('tests/data/model_pollutants.inp') as sim:
+        ...     C1 = Links(sim)["C1"]
         ...     for step in sim:
         ...         print(C1.pollut_quality)
-        >>> {'test-pollutant': 0.0}
-        >>> {'test-pollutant': 120.0}
-        >>> {'test-pollutant': 120.0}
+        {'test-pollutant': 0.0}
+        {'test-pollutant': 120.0}
+        {'test-pollutant': 120.0}
         """
         out_dict = {}
         pollut_ids = self._model.getObjectIDList(ObjectType.POLLUT.value)
@@ -891,6 +888,29 @@ class Link(object):
 
         return out_dict
 
+    @pollut_quality.setter
+    def pollut_quality(self, args):
+        """
+        Set Current Link Water Quality Value
+        
+        Examples:
+
+        >>> from pyswmm import Simulation, Links
+        >>>
+        >>> with Simulation('tests/data/model_pollutants_setters.inp') as sim:
+        ...     C1 = Links(sim)["C1"]
+        ...     for step in sim:
+        ...         C1.pollut_quality = ('test-pollutant', 100)
+                    print(C1.pollut_quality)
+        {'test-pollutant': 100.0}
+        {'test-pollutant': 100.0}
+        {'test-pollutant': 100.0}
+        """
+
+        pollutant_ID, pollutant_value = args
+
+        self._model.setLinkPollut(self._linkid, pollutant_ID, pollutant_value)
+
     @property
     def total_loading(self):
         """
@@ -906,13 +926,13 @@ class Link(object):
 
         >>> from pyswmm import Simulation, Links
         >>>
-        >>> with Simulation('tests/buildup-test.inp') as sim:
-        ...     C1 = Nodes(sim)["C1"]
+        >>> with Simulation('tests/data/model_pollutants.inp') as sim:
+        ...     C1 = Links(sim)["C1"]
         ...     for step in sim:
         ...         print(C1.total_loading)
-        >>> {'test-pollutant': 0.01}
-        >>> {'test-pollutant': 0.02}
-        >>> {'test-pollutant': 0.03}
+        {'test-pollutant': 0.01}
+        {'test-pollutant': 0.02}
+        {'test-pollutant': 0.03}
         """
         out_dict = {}
         pollut_ids = self._model.getObjectIDList(ObjectType.POLLUT.value)
@@ -924,6 +944,38 @@ class Link(object):
 
         return out_dict
 
+    @property
+    def reactor_quality(self):
+        """
+        Get Current Water Quality Values for the mixed reactor inside a Link.
+        If Simulation is not running this method will raise a warning and
+        return 0.
+
+        :return: Group of Water Quality Values.
+        :rtype: dict
+
+        Examples:
+
+        >>> from pyswmm import Simulation, Links
+        >>>
+        >>> with Simulation('tests/data/model_pollutants.inp') as sim:
+        ...     C1 = Links(sim)["C1"]
+        ...     for step in sim:
+        ...         print(C1.reactor_quality)
+        {'test-pollutant': 0.0}
+        {'test-pollutant': 120.0}
+        {'test-pollutant': 120.0}
+        """
+        out_dict = {}
+        pollut_ids = self._model.getObjectIDList(ObjectType.POLLUT.value)
+        quality_array = self._model.getLinkPollut(self._linkid,
+                                                      LinkPollut.linkQual.value)
+
+        for ind in range(len(pollut_ids)):
+            out_dict[pollut_ids[ind]] = quality_array[ind]
+
+        return out_dict
+
 
 class Conduit(Link):
     """
@@ -981,6 +1033,37 @@ class Conduit(Link):
 
         :return: Group of Stats
         :rtype: dict
+
+        Examples:
+
+        >>> from pyswmm import Simulation, Links
+        >>> import pprint
+        >>> pp = pprint.PrettyPrinter(indent=4)
+        >>>
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:        
+        ...     c1c2 = Links(sim)["C1:C2"]
+        ...     print(c1c2.flow)
+        ...     for step in sim:
+        ...         pass
+        ...     pp.pprint(c1c2.conduit_statistics)        
+        o  Retrieving project data
+        {   'flow_turn_sign': -1,
+            'flow_turns': 1,
+            'peak_depth': 0.8744979811226141,
+            'peak_flow': 9.612897240188659,
+            'peak_flow_date': 42310.00000579861,
+            'peak_velocity': 13.200109870715737,
+            'time_capacity_limited': 0.0,
+            'time_courant_crit': 0.0,
+            'time_full_downstream': 0.0,
+            'time_full_flow': 57.98847222222222,
+            'time_full_upstream': 57.98902777777778,
+            'time_in_flow_class': <Swig Object of type 'DateTime *' at 0x7f7d591269a0>,
+            'time_inlet_control': 0.0,
+            'time_normal_flow': 0.0001388888888888889,
+            'time_surcharged': 0.0
+        }
+
         """
         return self._model.conduit_statistics(self.linkid)
 
@@ -1023,5 +1106,29 @@ class Pump(Link):
 
         :return: Group of Stats
         :rtype: dict
+
+        Examples:
+
+        >>> from pyswmm import Simulation, Links
+        >>> import pprint
+        >>> pp = pprint.PrettyPrinter(indent=4)
+        >>>        
+        >>> with Simulation('tests/data/model_pump_setting.inp') as sim:        
+        ...     c3 = Links(sim)["C3"]
+        ...     for step in sim:
+        ...         pass
+        ...     pp.pprint(c3.pump_statistics)        
+        o  Retrieving project data
+        {   'average_flowrate': 20.0,
+            'energy_consumed': 2792.5975765384896,
+            'max_flowrate': 20.0,
+            'min_flowrate': 0.0,
+            'number_startups': 1,
+            'off_curve_high': 0.0,
+            'off_curve_low': 0.0,
+            'percent_utilized': 208800.0,
+            'total_periods': 208801,
+            'total_volume': 4176000.0
+        }
         """
         return self._model.pump_statistics(self.linkid)
