@@ -109,8 +109,6 @@ class RainGages(object):
         else:
             raise StopIteration()
 
-    next = __next__  # Python 2
-
     @property
     def _raingageid(self):
         """Node ID."""
@@ -131,7 +129,7 @@ class RainGage(object):
     >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
     ...     rg1 = Raingages(sim)["Gage1"]
     ...     print(rg1.raingageid)
-    ...     for step in simulation:
+    ...     for step in sim:
     ...         print(rg1.total_precip)
     ... Gage1
     ... 0
