@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Copyright (c) 2014 Bryant E. McDonnell
+# Copyright (c) 2023 Bryant E. McDonnell (See AUTHORS)
 #
 # Licensed under the terms of the BSD2 License
 # See LICENSE.txt for details
 # -----------------------------------------------------------------------------
 """Base class for a SWMM Simulation."""
 
+# Standard import
+from warnings import warn
+
 # Local imports
 from pyswmm.swmm5 import PySWMM, PYSWMMException
 from pyswmm.toolkitapi import SimulationTime, SimulationUnits
@@ -28,24 +31,12 @@ class Simulation(object):
 
     Examples:
 
-    Intialize a simulation and iterate through a simulation. This
-    approach requires some clean up.
-
-    >>> from pyswmm import Simulation
-    >>>
-    >>> sim = Simulation('tests/data/TestModel1_weirSetting.inp')
-    >>> for step in sim:
-    ...     pass
-    >>>
-    >>> sim.report()
-    >>> sim.close()
-
     Intialize using with statement.  This automatically cleans up
     after a simulation
 
     >>> from pyswmm import Simulation
     >>>
-    >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+    >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
     ...     for step in sim:
     ...         pass
     ...     sim.report()
@@ -56,7 +47,7 @@ class Simulation(object):
 
     >>> from pyswmm import Simulation
     >>>
-    >>> sim = Simulation('tests/data/TestModel1_weirSetting.inp')
+    >>> sim = Simulation('tests/data/model_weir_setting.inp')
     >>> sim.execute()
     """
 
@@ -73,6 +64,7 @@ class Simulation(object):
         self._terminate_request = False
         self._callbacks = {
             "before_start": None,
+            "after_start": None,
             "before_step": None,
             "after_step": None,
             "before_end": None,
@@ -86,15 +78,14 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     for step in sim:
         ...         print(sim.current_time)
         ...     sim.report()
-        >>>
-        >>> 2015-11-01 14:00:30
-        >>> 2015-11-01 14:01:00
-        >>> 2015-11-01 14:01:30
-        >>> 2015-11-01 14:02:00
+        2015-11-01 14:00:30
+        2015-11-01 14:01:00
+        2015-11-01 14:01:30
+        2015-11-01 14:02:00
         """
         return self
 
@@ -105,13 +96,13 @@ class Simulation(object):
     def start(self):
         """Start Simulation"""
         if not self._isStarted:
-            # Set Model Initial Conditions
-            # (This Will be Deprecated with Time)
             if hasattr(self, "_initial_conditions"):
                 self._initial_conditions()
-            # Execute Callback Hooks Before Simulation
+            # Execute Callback Hooks Before Start
             self._execute_callback(self.before_start())
             self._model.swmm_start(True)
+            # Execute Callback Hooks After Start
+            self._execute_callback(self.after_start())
             self._isStarted = True
 
     def __next__(self):
@@ -136,8 +127,6 @@ class Simulation(object):
             raise StopIteration
         return self._model
 
-    next = __next__  # Python 2
-
     def __exit__(self, *a):
         """close"""
         if self._isStarted:
@@ -172,13 +161,20 @@ class Simulation(object):
 
     def initial_conditions(self, init_conditions):
         """
+        DEPRECATION WARNING - 2023/06/10
+
+        Starting in PySWMM-v2 this method/function is set to be
+        deprecated.  For setting initial depths refer to the
+        Simulation.add_before_start() callback. If the user's goal is to
+        set the initial link settings, instead use Simulation.add_after_start().
+
         Intial Conditions for Hydraulics and Hydrology can be set
         from within the api by setting a function to the
         initial_conditions property.
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('./TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     nodeJ1 = Nodes(sim)["J1"]
         ...
         ...     def init_conditions():
@@ -191,6 +187,9 @@ class Simulation(object):
         ...     sim.report()
 
         """
+        warn('This method will be deprecated in PySWMM-v2',
+             DeprecationWarning, stacklevel=2)
+
         if self._is_callback(init_conditions):
             self._initial_conditions = init_conditions
 
@@ -213,7 +212,7 @@ class Simulation(object):
         >>> def test_callback():
         ...     print("CALLBACK - Executed")
         >>>
-        >>> with Simulation('./TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...
         ...     sim.before_start(test_callback) #<- pass function handle.
         ...     print("Waiting to Start")
@@ -221,18 +220,36 @@ class Simulation(object):
         ...         print("Step {}".format(ind))
         ...     print("Complete!")
         ... print("Closed")
-        >>>
-        >>> "Waiting to Start"
-        >>> "CALLBACK - Executed"
-        >>> "Step 0"
-        >>> "Step 1"
-        >>> ...
-        >>> "Complete!"
-        >>> "Closed"
+        "Waiting to Start"
+        "CALLBACK - Executed"
+        "Step 0"
+        "Step 1"
+        "Complete!"
+        "Closed"
         """
         if self._is_callback(callback):
             self._callbacks["before_start"] = callback
 
+    def after_start(self):
+        """Get After Start Callback.
+
+        :return: Callbacks
+        """
+        return self._callbacks["after_start"]
+
+    def add_after_start(self, callback):
+        """
+        Add callback function/method/object to execute after
+        a simlation start. Needs to be callable.  This callback allows
+        setting initial link target_settings (such as an orifice).
+
+        :param func callback: Callable Object
+
+        (See self.add_after_start() for more details)
+        """
+        if self._is_callback(callback):
+            self._callbacks["after_start"] = callback
+
     def before_step(self):
         """Get Before Step Callback.
 
@@ -341,17 +358,16 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
-        ...     sim.step_advance(300)
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...     sim.step_advance(30)
         ...     for step in sim:
-        ...         print(step.current_time)
+        ...         print(sim.current_time)
         ...         # or here! sim.step_advance(newvalue)
         ...     sim.report()
-        >>>
-        >>> 2015-11-01 14:00:30
-        >>> 2015-11-01 14:01:00
-        >>> 2015-11-01 14:01:30
-        >>> 2015-11-01 14:02:00
+        2015-11-01 14:00:30
+        2015-11-01 14:01:00
+        2015-11-01 14:01:30
+        2015-11-01 14:02:00
         """
         self._advance_seconds = advance_seconds
 
@@ -385,7 +401,7 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     for step in sim:
         ...         pass
         ...     sim.report()
@@ -401,7 +417,7 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> sim = Simulation('./TestModel1_weirSetting.inp')
+        >>> sim = Simulation('tests/data/model_weir_setting.inp')
         >>> for step in sim:
         ...     pass
         >>>
@@ -416,7 +432,7 @@ class Simulation(object):
 
         Examples:
 
-        >>> sim = PYSWMM(r'\\test.inp')
+        >>> sim = Simulation('tests/data/model_weir_setting.inp')
         >>> sim.execute()
         """
         self._model.swmmExec()
@@ -427,13 +443,13 @@ class Simulation(object):
         Retrieves the SWMM Engine Version.
 
         :return: Engine Version
-        :rtype: StrictVersion
+        :rtype: LooseVersion
 
         Examples:
 
-        >>> sim = PYSWMM(r'\\test.inp')
-        >>> sim.engine_version
-        StrictVersion("5.1.13")
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...     print(sim.engine_version)
+        5.1.14
         """
         return self._model.swmm_getVersion()
 
@@ -447,9 +463,9 @@ class Simulation(object):
 
         Examples:
 
-        >>> sim = PYSWMM(r'\\test.inp')
-        >>> sim.execute()
-        >>> sim.runoff_error
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...    sim.execute()
+        ...    print(sim.runoff_error)
         0.01
         """
         return self._model.swmm_getMassBalErr()[0]
@@ -464,9 +480,9 @@ class Simulation(object):
 
         Examples:
 
-        >>> sim = PYSWMM(r'\\test.inp')
-        >>> sim.execute()
-        >>> sim.flow_routing_error
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...    sim.execute()
+        ...    print(sim.flow_routing_error)
         0.01
         """
         return self._model.swmm_getMassBalErr()[1]
@@ -481,9 +497,9 @@ class Simulation(object):
 
         Examples:
 
-        >>> sim = PYSWMM(r'\\test.inp')
-        >>> sim.execute()
-        >>> sim.quality_error
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...    sim.execute()
+        ...    print(sim.quality_error)
         0.01
         """
         return self._model.swmm_getMassBalErr()[2]
@@ -496,11 +512,10 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
-        ...     print sim.start_time
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...     print(sim.start_time)
         ...     sim.start_time = datetime(2015,5,10,15,15,1)
-        >>>
-        >>> datetime.datetime(2015,5,10,15,15,1)
+        datetime.datetime(2015,5,10,15,15,1)
         """
         return self._model.getSimulationDateTime(
             SimulationTime.StartDateTime.value)
@@ -519,11 +534,10 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
-        ...     print sim.end_time
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...     print(sim.end_time)
         ...     sim.end_time = datetime(2016,5,10,15,15,1)
-        >>>
-        >>> datetime.datetime(2016,5,10,15,15,1)
+        datetime.datetime(2016,5,10,15,15,1)
         """
         return self._model.getSimulationDateTime(
             SimulationTime.EndDateTime.value)
@@ -542,11 +556,10 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
-        ...     print sim.report_start
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...     print(sim.report_start)
         ...     sim.report_start = datetime(2015,5,10,15,15,1)
-        >>>
-        >>> datetime.datetime(2015,5,10,15,15,1)
+        datetime.datetime(2015,5,10,15,15,1)
         """
         return self._model.getSimulationDateTime(
             SimulationTime.ReportStart.value)
@@ -569,10 +582,9 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
-        ...     print sim.flow_units
-        >>>
-        >>> CFS
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...     print(sim.flow_units)
+        CFS
         """
         return self._model.getSimUnit(SimulationUnits.FlowUnits.value)
 
@@ -587,10 +599,9 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
-        ...     print sim.system_units
-        >>>
-        >>> US
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
+        ...     print(sim.system_units)
+        US
         """
         return self._model.getSimUnit(SimulationUnits.UnitSystem.value)
 
@@ -605,15 +616,14 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     for step in sim:
         ...         print(sim.current_time)
         ...     sim.report()
-        >>>
-        >>> 2015-11-01 14:00:30
-        >>> 2015-11-01 14:01:00
-        >>> 2015-11-01 14:01:30
-        >>> 2015-11-01 14:02:00
+        2015-11-01 14:00:30
+        2015-11-01 14:01:00
+        2015-11-01 14:01:30
+        2015-11-01 14:02:00
         """
         return self._model.getCurrentSimulationTime()
 
@@ -628,16 +638,37 @@ class Simulation(object):
 
         >>> from pyswmm import Simulation
         >>>
-        >>> with Simulation('tests/data/TestModel1_weirSetting.inp') as sim:
+        >>> with Simulation('tests/data/model_weir_setting.inp') as sim:
         ...     for step in sim:
         ...         print(sim.percent_complete)
         ...     sim.report()
-        >>>
-        >>> 0.01
-        >>> 0.25
-        >>> 0.50
-        >>> 0.75
+        0.01
+        0.25
+        0.50
+        0.75
         """
         dt = self.current_time - self.start_time
         total_time = self.end_time - self.start_time
         return float(dt.total_seconds()) / total_time.total_seconds()
+
+    def use_hotstart(self,hotstart_file):
+        """
+        Use a hotstart file to initialize the simulation.
+
+        This must be run before the simualation loop but inside
+        the simulation context manager.
+
+        :param str hotstart_file: Path to hotstart file.
+        """
+        self._model.swmm_use_hotstart(hotstart_file)
+
+    def save_hotstart(self,hotstart_file):
+
+        """
+        Save the current state of the model to a hotstart file.
+
+        This can be run at any point during the simultion.
+
+        :param str hotstart_file: Path to hotstart file.
+        """
+        self._model.swmm_save_hotstart(hotstart_file)
