@@ -1,18 +1,16 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Copyright (c) 2014 Bryant E. McDonnell
+# Copyright (c) 2023 Bryant E. McDonnell (See AUTHORS)
 #
 # Licensed under the terms of the BSD2 License
 # See LICENSE.txt for details
 # -----------------------------------------------------------------------------
 """
 Python extensions for the SWMM5 Programmers toolkit.
-
-Open Water Analytics (http://wateranalytics.org/)
 """
 
 # Standard library imports
-import distutils.version
+import packaging.version
 import sys
 from datetime import datetime
 
@@ -22,8 +20,9 @@ from swmm.toolkit import solver
 # Local imports
 import pyswmm.toolkitapi as tka
 
-# Local variables
-SWMM_VER_51011 = '5.1.14'
+# Monkey Patching
+from pyswmm._monkey_patch import _patch_solver
+_patch_solver(solver)
 
 
 class SWMMException(Exception):
@@ -39,7 +38,7 @@ class SWMMException(Exception):
 
 
 class PYSWMMException(Exception):
-    """Custom exception class for PySWMM errors. """
+    """Custom exception class for PySWMM errors."""
 
     def __init__(self, error_message):
         self.warning = False
@@ -88,7 +87,7 @@ class PySWMM(object):
 
     >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
     >>> swmm_model.swmm_open()
-    >>> swmm_model.swmm_start()
+    >>> swmm_model.swmm_start(True)
     >>> while(True):
     ...     time = swmm_model.swmm_step() # or swmm_stride()
     ...     if (time <= 0.0): break
@@ -119,6 +118,7 @@ class PySWMM(object):
         self.inpfile = inpfile
         self.rptfile = rptfile
         self.binfile = binfile
+
         self.curSimTime = 0.0
 
     def swmmExec(self, inpfile=None, rptfile=None, binfile=None):
@@ -230,7 +230,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
         ...     if (time <= 0.0): break
@@ -249,7 +249,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
         ...     if (time <= 0.0): break
@@ -268,7 +268,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
         ...     if (time <= 0.0): break
@@ -297,7 +297,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_stride(600)
         ...     if (time <= 0.0): break
@@ -328,7 +328,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
         ...     if (time <= 0.0): break
@@ -347,7 +347,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
         ...     if (time <= 0.0): break
@@ -359,6 +359,26 @@ class PySWMM(object):
         solver.swmm_close()
         self.fileLoaded = False
 
+    def swmm_save_hotstart(self, hotstart_filename):
+        """
+        Save the current state of the model to a hotstart file.
+
+        This can be run at any point during the simultion.
+
+        :param str hotstart_filename: Name of hotstart file to save to.
+        """
+        solver.swmm_hotstart(tka.HotstartFile.save,hotstart_filename)
+
+    def swmm_use_hotstart(self, hotstart_filename):
+        """
+        Use a hotstart file to initialize the model.
+
+        This must be run before swmm_start() and after swmm_open().
+
+        :param str hotstart_filename: Name of hotstart file to load from.
+        """
+        solver.swmm_hotstart(tka.HotstartFile.use,hotstart_filename)
+
     def swmm_getVersion(self):
         """
         Retrieves version number of current SWMM engine.
@@ -369,8 +389,8 @@ class PySWMM(object):
         :return: version number of the DLL source code
         :rtype: int
         """
-        major, minor, patch = solver.swmm_version_info()
-        return distutils.version.LooseVersion('.'.join([major, minor, patch]))
+        major, minor, patch = solver.swmm_version_info().split('.')
+        return packaging.version.parse('.'.join([major, minor, patch]))
 
         return
     def swmm_getMassBalErr(self):
@@ -397,11 +417,11 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getSimulationDateTime(SimulationTime.StartDateTime)
-        >>> 2015-11-01 14:00:00
+        2015-11-01 14:00:00
         >>> swmm_model.getSimulationDateTime(SimulationTime.EndDateTime)
-        >>> 2015-11-04 00:00:00
+        2015-11-04 00:00:00
         >>> swmm_model.getSimulationDateTime(SimulationTime.ReportStart)
-        >>> 2015-11-01 14:00:00
+        2015-11-01 14:00:00
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -421,7 +441,7 @@ class PySWMM(object):
                                              datetime(2009, 10, 1, 12,30))
         >>>
         """
-        solver.simulation_set_datetime(timeType, newDateTime.year, newDateTime.month, 
+        solver.simulation_set_datetime(timeType, newDateTime.year, newDateTime.month,
             newDateTime.day, newDateTime.hour, newDateTime.minute, newDateTime.second)
 
     def getSimUnit(self, unit_type):
@@ -437,7 +457,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getSimUnit(SimulationUnits.FlowUnits)
-        >>> CFS
+        CFS
         >>> swmm_model.swmm_close()
         """
         value = solver.simulation_get_unit(unit_type)
@@ -465,7 +485,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getSimAnalysisSetting(SimAnalysisSettings.AllowPonding)
-        >>> False
+        False
         >>> swmm_model.swmm_close()
         """
         return bool(solver.simulation_get_setting(setting_type))
@@ -483,7 +503,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getSimAnalysisSetting(SimulationParameters.RouteStep)
-        >>> 300
+        300
         >>> swmm_model.swmm_close()
         """
         return solver.simulation_get_parameter(param_type)
@@ -501,7 +521,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getProjectSize(ObjectType.NODE)
-        >>> 10
+        10
         >>> swmm_model.swmm_close()
         """
         return solver.project_get_count(object_type)
@@ -520,7 +540,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getObjectId(ObjectType.NODE,35)
-        >>> "example_id_name"
+        "example_id_name"
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -537,7 +557,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getObjectIDList(ObjectType.LINK)
-        >>> ['C1:C2', 'C2', 'C3']
+        ['C1:C2', 'C2', 'C3']
         >>>
         >>> swmm_model.swmm_close()
         >>>
@@ -573,10 +593,10 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getNodeType('J1')
-        >>> 0
+        0
         >>>
         >>> swmm_model.getNodeType('J1') is NodeType.junction
-        >>> True
+        True
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -596,10 +616,10 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLinkType('C1')
-        >>> 3
+        3
         >>>
         >>> swmm_model.getLinkType('C1') is LinkType.weir
-        >>> True
+        True
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -627,7 +647,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLinkConnections('C1')
-        >>> ('NodeUSID','NodeDSID')
+        ('NodeUSID','NodeDSID')
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -670,7 +690,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getNodeParam('J2',NodeParams.invertElev )
-        >>> 13.392
+        13.392
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -709,7 +729,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLinkParam('C1:C2',LinkParams.offset1 )
-        >>> 0.0
+        0.0
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -746,7 +766,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLidCOverflow('J2')
-        >>> True
+        True
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -787,7 +807,6 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.setLidCParam('J2', LidLayer.surface, LidLayersProperty.thickness, 110)
-
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -806,7 +825,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLidUCount('J2')
-        >>> 2
+        2
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -828,7 +847,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLidUParam('S2', 0, LidUParams.unitarea)
-        >>> 1000
+        1000
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -869,7 +888,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLidUOption('S2', 0, LidUParams.index)
-        >>> 1000
+        1000
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -909,7 +928,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getLinkParam('S2',SubcParams.area )
-        >>> 43561.596096880996
+        43561.596096880996
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -955,11 +974,11 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getSubcatchOutConnection('S2',SubcParams.area )
-        >>> (2, 'J2')
+        (2, 'J2')
         >>>
         >>> subout = swmm_model.getSubcatchOutConnection('S2',SubcParams.area )
         >>> subout[0]  == ObjectType.NODE
-        >>> True
+        True
         >>>
         >>> swmm_model.swmm_close()
         """
@@ -986,7 +1005,7 @@ class PySWMM(object):
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
         >>> swmm_model.getGagePrecip('Gage1', )
-        >>> 0.0
+        0.0
         >>> swmm_model.swmm_close()
 
         """
@@ -1006,16 +1025,15 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
-        ...     print swmm_model.getCurrentSimualationTime()
+        ...     print(swmm_model.getCurrentSimualationTime())
         ...     if (time <= 0.0): break
-        ...
-        >>> 2015-11-03 10:10:12
-        >>> 2015-11-03 10:20:12
-        >>> 2015-11-03 10:30:12
-        >>> 2015-11-03 10:40:12
+        2015-11-03 10:10:12
+        2015-11-03 10:20:12
+        2015-11-03 10:30:12
+        2015-11-03 10:40:12
         >>>
         >>> swmm_model.swmm_end()
         >>> swmm_model.swmm_report()
@@ -1036,16 +1054,15 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
-        ...     print swmm_model.getLidUFluxRates('J1', 0, LidLayers.surface)
+        ...     print(swmm_model.getLidUFluxRates('J1', 0, LidLayers.surface))
         ...     if (time <= 0.0): break
-        ...
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        1.2
+        1.5
+        1.9
+        1.2
         >>>
         >>> swmm_model.swmm_end()
         >>> swmm_model.swmm_report()
@@ -1069,16 +1086,15 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
-        ...     print swmm_model.getLidUResult('J1', 0, LidUResults.inflow)
+        ...     print(swmm_model.getLidUResult('J1', 0, LidUResults.inflow))
         ...     if (time <= 0.0): break
-        ...
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        1.2
+        1.5
+        1.9
+        1.2
         >>>
         >>> swmm_model.swmm_end()
         >>> swmm_model.swmm_report()
@@ -1101,16 +1117,15 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
-        ...     print swmm_model.getLidGResult('J1', LidUResults.flowToPerv)
+        ...     print(swmm_model.getLidGResult('J1', LidUResults.flowToPerv))
         ...     if (time <= 0.0): break
-        ...
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        1.2
+        1.5
+        1.9
+        1.2
         >>>
         >>> swmm_model.swmm_end()
         >>> swmm_model.swmm_report()
@@ -1132,16 +1147,15 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
-        ...     print swmm_model.getNodeResult('J1', NodeResults.newDepth)
+        ...     print(swmm_model.getNodeResult('J1', NodeResults.newDepth))
         ...     if (time <= 0.0): break
-        ...
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        1.2
+        1.5
+        1.9
+        1.2
         >>>
         >>> swmm_model.swmm_end()
         >>> swmm_model.swmm_report()
@@ -1155,7 +1169,7 @@ class PySWMM(object):
         Get water quality results from a Node.
 
         :param str ID: Node ID
-        :param int result_type: parameter (toolkitapi.NodePollut)
+        :param int result_type: parameter (toolkitapi.NodePollut member value)
         :rtype: list
         """
         index = self.getObjectIDIndex(tka.ObjectType.NODE.value, ID)
@@ -1173,16 +1187,15 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
-        ...     print swmm_model.getLinkResult('J1', LinkResults.newFlow)
+        ...     print(swmm_model.getLinkResult('J1', LinkResults.newFlow))
         ...     if (time <= 0.0): break
-        ...
-        >>> 1.2
-        >>> 1.5
-        >>> 1.9
-        >>> 1.2
+        1.2
+        1.5
+        1.9
+        1.2
         >>>
         >>> swmm_model.swmm_end()
         >>> swmm_model.swmm_report()
@@ -1196,8 +1209,8 @@ class PySWMM(object):
         Get water quality results from a Link.
 
         :param str ID: Link ID
-        :param int result_type:  parameter (toolkitapi.LinkPollut)
-        :return: Pollutant Values
+        :param int result_type:  parameter (toolkitapi.LinkPollut member value)
+        :return: Pollutant Value
         :rtype: list
         """
         index = self.getObjectIDIndex(tka.ObjectType.LINK.value, ID)
@@ -1217,16 +1230,15 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> while(True):
         ...     time = swmm_model.swmm_step()
-        ...     print swmm_model.getSubcatchResult('S3', SubcResults.newRunoff)
+        ...     print(swmm_model.getSubcatchResult('S3', SubcResults.newRunoff))
         ...     if (time <= 0.0): break
-        ...
-        >>> 0.01
-        >>> 0.05
-        >>> 0.09
-        >>> 0.08
+        0.01
+        0.05
+        0.09
+        0.08
         >>>
         >>> swmm_model.swmm_end()
         >>> swmm_model.swmm_report()
@@ -1418,12 +1430,11 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> i = 0
         >>> while(True):
         ...     time = swmm_model.swmm_step()
         ...     i+=1
-        ...
         ...     if i == 80:
         ...         swmm_model.setLinkSetting('C3',0.5)
         ...     if (time <= 0.0): break
@@ -1450,7 +1461,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> i = 0
         >>> while(True):
         ...     if i == 80:
@@ -1481,7 +1492,7 @@ class PySWMM(object):
 
         >>> swmm_model = PySWMM(r'\\.inp',r'\\.rpt',r'\\.out')
         >>> swmm_model.swmm_open()
-        >>> swmm_model.swmm_start()
+        >>> swmm_model.swmm_start(True)
         >>> i = 0
         >>> while(True):
         ...     if i == 80:
@@ -1519,6 +1530,29 @@ class PySWMM(object):
         index = self.getObjectIDIndex(tka.ObjectType.GAGE.value, ID)
         solver.raingage_set_precipitation(index, value)
 
+    def setNodePollut(self, ID, pollutant_ID, pollutant_value):
+        """
+        Set water quality results in a Node.
+
+        :param str ID: Node ID
+        :param str pollutant_ID
+        :param float pollutant_value: pollutant value to set
+        """
+        index = self.getObjectIDIndex(tka.ObjectType.NODE.value, ID)
+        pollutant_index = self.getObjectIDIndex(tka.ObjectType.POLLUT.value, pollutant_ID)
+        solver.node_set_pollutant(index, tka.NodePollut.nodeQual.value, pollutant_index, pollutant_value)
+
+    def setLinkPollut(self, ID, pollutant_ID, pollutant_value):
+        """
+        Set water quality results in a Link.
+
+        :param str ID: Link ID
+        :param str ID: Pollutant ID
+        :param float pollutant_value: pollutant value to set
+        """
+        index = self.getObjectIDIndex(tka.ObjectType.LINK.value, ID)
+        pollutant_index = self.getObjectIDIndex(tka.ObjectType.POLLUT.value, pollutant_ID)
+        solver.link_set_pollutant(index, tka.LinkPollut.linkQual.value, pollutant_index, pollutant_value)
 
 if __name__ == '__main__':
     test = PySWMM(
