@@ -5,13 +5,15 @@
 # Licensed under the terms of the BSD2 License
 # See LICENSE.txt for details
 # -----------------------------------------------------------------------------
+from datetime import datetime
 
 # Third party imports
 import pytest
 
 # Local imports
-from pyswmm import Simulation
-from pyswmm.swmm5 import PySWMM, PYSWMMException, SWMMException
+from pyswmm import Simulation, Output
+from pyswmm.swmm5 import PySWMM, PYSWMMException
+from pyswmm.errors import OutputException
 from pyswmm.tests.data import MODEL_WEIR_SETTING_PATH, MODEL_BAD_INPUT_PATH_1
 from pyswmm.utils.fixtures import get_model_files
 
@@ -40,3 +42,19 @@ def test_swmm_input_error_1():
             for step in sim:
                 pass
     assert(str(e.value).strip() == 'ERROR 200: one or more errors in input file.')
+
+
+def test_error_output():
+    with Simulation(MODEL_WEIR_SETTING_PATH) as sim:
+        for step in sim:
+            pass
+
+    with Output(MODEL_WEIR_SETTING_PATH.replace('inp', 'out')) as out:
+        with pytest.raises(OutputException):
+            out.node_series('potato', 'total_inflow')
+
+        with pytest.raises(OutputException):
+            out.link_series('C3', 'flow_rate', datetime(2021, 1, 1))
+
+        with pytest.raises(OutputException):
+            out.link_series('C3', 'flow_rate', datetime(2015, 11, 4), datetime(2021, 1, 1))
\ No newline at end of file
