@@ -1,5 +1,6 @@
 from pyswmm import Simulation, RainGages, SystemStats
 from pyswmm.tests.data import MODEL_RAIN
+from pyswmm.toolkitapi import RainGageResults
 
 
 def test_api_rainfall():
@@ -9,9 +10,9 @@ def test_api_rainfall():
         sim._model.setGagePrecip("Gage1", 10.00)
         for ind, step in enumerate(sim):
             sim._model.setGagePrecip("Gage1", 10.00)
-            x = sim._model.getGagePrecip("Gage1")
+            x = sim._model.getGagePrecip("Gage1", RainGageResults.total_precip)
 
-            if round(x[0], 2) == 10.0:
+            if round(x, 2) == 10.0:
                 check += 1
     assert(check == 718)
 
@@ -23,7 +24,7 @@ def test_rainfall():
 
         sim.step_advance(3600)
         for ind, step in enumerate(sim):
-            if ind > 0 and ind < 5:
+            if 0 < ind < 5:
                 assert(rg.total_precip == 1)
                 assert(rg.rainfall == 1)
                 assert(rg.snowfall == 0)
