@@ -7,16 +7,14 @@
 # -----------------------------------------------------------------------------
 
 # Standard library imports
-import pytest
 from random import randint
-import sys
 
 # Local imports
 import pyswmm.toolkitapi as tka
 from pyswmm import Links, Nodes, Simulation
 from pyswmm.tests.data import MODEL_WEIR_SETTING_PATH
-from pyswmm.swmm5 import SWMMException
-
+import pytest
+import os
 
 def test_simulation_1():
     sim = Simulation(MODEL_WEIR_SETTING_PATH)
@@ -89,6 +87,11 @@ def test_simulation_callback_1():
 
         sim.add_before_start(before_start1)
 
+        def after_start1():
+            LIST.append("after_start1")
+
+        sim.add_after_start(after_start1)
+
         def before_step1():
             if "before_step1" not in LIST:
                 LIST.append("before_step1")
@@ -124,8 +127,8 @@ def test_simulation_callback_1():
                 LIST.append("SIM_STEP")
 
     assert LIST == [
-        "OPENED", "before_start1", "before_step1", "after_step1", "SIM_STEP",
-        "before_end1", "after_end1", "after_close1"
+        "OPENED", "before_start1", "after_start1", "before_step1",
+        "after_step1", "SIM_STEP", "before_end1", "after_end1", "after_close1"
     ]
     print(LIST)
 
@@ -138,3 +141,33 @@ def test_simulation_terminate():
             if ind == 10:
                 sim.terminate_simulation()
         assert(i == 11)
+
+def test_hotstart():
+    HSF_PATH = MODEL_WEIR_SETTING_PATH.replace('.inp', '.hsf')
+    if os.path.exists(HSF_PATH):
+        os.remove(HSF_PATH)
+    
+    # test saving hotstart works
+    assert not os.path.exists(HSF_PATH)
+
+    with Simulation(MODEL_WEIR_SETTING_PATH) as sim:
+        J1 = Nodes(sim)["J1"]
+        for ind, step in enumerate(sim):
+            if ind == 10:
+                sim.save_hotstart(HSF_PATH)
+                J1_dep = J1.depth
+                break
+    
+    assert os.path.exists(HSF_PATH)
+
+    # test loading hotstart works and that data matches
+    with Simulation(MODEL_WEIR_SETTING_PATH) as sim:
+        def store_J1_depth_before_step():
+            sim.J1_depth = Nodes(sim)["J1"].depth
+        sim.add_before_step(store_J1_depth_before_step)
+        sim.use_hotstart(HSF_PATH)
+
+        for ind, step in enumerate(sim):
+            break
+    assert sim.J1_depth == pytest.approx(J1_dep, 0.00001)
+    
\ No newline at end of file
