@@ -6,7 +6,7 @@
 # See LICENSE.txt for details
 # -----------------------------------------------------------------------------
 """SWMM Object Enum."""
-
+from swmm.toolkit import shared_enum
 # Standard library imports
 from enum import Enum
 import ctypes
@@ -88,10 +88,13 @@ class NodeResults(Enum):
     newDepth = 5  # Current water depth
     newHead = 6  # Current water head
     newLatFlow = 7  # Current Lateral Inflow
+    hyd_res_time = 8  # Current hydraulic retention time
 
 
 class NodePollut(Enum):
     nodeQual = 0  # Current Water Quality Value
+    inflowQual = 1  # Current inflow water quality value
+    reactorQual = 2  # Current quality value in the mixed reactor
 
 
 class NodeType(Enum):
@@ -126,6 +129,7 @@ class LinkResults(Enum):
 class LinkPollut(Enum):
     linkQual = 0  # Current Water Quality Value
     totalLoad = 1  # Total Quality Mass Loading
+    reactorQual = 2  # Current quality value in the mixed reactor
 
 
 class LinkType(Enum):
@@ -252,6 +256,11 @@ class RainGageResults(Enum):
     snowfall = 2
 
 
+class HotstartFile(Enum):
+    use = 0
+    save = 1
+
+
 class NodeStats(ctypes.Structure):
     _fields_ = [
         ("avgDepth", ctypes.c_double), ("maxDepth", ctypes.c_double),
@@ -530,4 +539,4 @@ class SMO_systemAttribute(Enum):
     flood_losses = 10
     outfall_flows = 11
     volume_stored = 12
-    evap_rate = 13
+    evap_rate = 13
\ No newline at end of file
